OH_NativeVSync_RequestFrameWithMultiCallback

Function OH_NativeVSync_RequestFrameWithMultiCallback 

pub unsafe extern "C" fn OH_NativeVSync_RequestFrameWithMultiCallback(
    nativeVsync: *mut OH_NativeVSync,
    callback: OH_NativeVSync_FrameCallback,
    data: *mut c_void,
) -> c_int
Available on crate feature api-12 only.
Request next vsync with callback. If this function is called multiple times in one vsync period, all these callbacks and dataset will be called.

Required System Capabilities: SystemCapability.Graphic.Graphic2D.NativeVsync

Arguments

  • nativeVsync - Indicates the pointer to a NativeVsync.

  • callback - Indicates the OH_NativeVSync_FrameCallback which will be called when next vsync coming.

  • data - Indicates data which will be used in callback.

Returns

  • [NATIVE_ERROR_OK] 0 - Success. [NATIVE_ERROR_INVALID_ARGUMENTS] 40001000 - the parameter nativeVsync is NULL or callback is NULL. [NATIVE_ERROR_BINDER_ERROR] 50401000 - ipc send failed.

Available since API-level: 12

Version: 1.0